package example2;

/**
 * Represents a roster for a course, tracking students and their scores.
 * Provides functionality to add students, display the roster, and calculate grades.
 */
public class Roster {
    public static final String SCHOOL = "UMCP"; // Name of the school (constant)
   Student[] allStudents; // Array to hold all registered students
    private String courseName; // Name of the course
    private int registered; // Number of students currently registered
    private static int totalRosters = 0; // Tracks total number of rosters created

    /**
     * Constructs a new roster for the specified course with a maximum capacity.
     * @param courseName the name of the course
     * @param totalSeats the maximum number of students allowed in the course
     */
    public Roster(String courseName, int totalSeats) {
        this.courseName = courseName;
        allStudents = new Student[totalSeats];
        registered = 0;
        totalRosters++;
    }

    /**
     * Adds a student to the roster if space is available.
     * @param name the name of the student
     * @param score the student's score (0-100)
     */
    public void addStudent(String name, int score) {
        if (registered < allStudents.length) {
            allStudents[registered++] = new Student(name, score);
        } else {
            System.out.println("Roster is full. Cannot add more students.");
        }
    }

    /**
     * Returns a string representation of the roster, including all students and their grades.
     * @return a formatted string with the roster details
     */
    public String toString() {
        StringBuilder answer = new StringBuilder(SCHOOL + "\n");
        answer.append("Course Name: ").append(courseName).append("\n");
        answer.append("Students Registered: ").append(registered).append("\n");
        answer.append("Students:\n");
        for (int idx = 0; idx < registered; idx++) {
            Student student = allStudents[idx];
            answer.append(student)
                  .append(", grade: ")
                  .append(findGrade(student.getScore()))
                  .append("\n");
        }
        return answer.toString();
    }

    /**
     * Returns the total number of rosters created.
     * @return the total number of rosters
     */
    public static int getTotalRosters() {
        return totalRosters;
    }

    /**
     * Determines the letter grade for a given score based on grade cutoffs.
     * @param score the score to evaluate
     * @return the letter grade corresponding to the score
     */
    private static char findGrade(int score) {
        int[] cutOffs = { 90, 80, 70, 60 };
        char[] letterGrades = { 'A', 'B', 'C', 'D', 'F' };

        for (int idx = 0; idx < cutOffs.length; idx++) {
            if (score >= cutOffs[idx]) {
                return letterGrades[idx];
            }
        }
        return 'F'; // Default to 'F' if no conditions are met
    }
}

