package example2;

/**
 * Represents a Student with a name and a score.
 * Demonstrates encapsulation and equality checking in Java.
 */
public class Student {
    private String name; // Name of the student
    private int score; // Score of the student (between 0 and 100)

    /**
     * Constructs a new Student with the given name and score.
     * @param name the name of the student
     * @param score the score of the student (0-100)
     */
    public Student(String name, int score) {
        this.name = name;
        this.score = score;
    }

    /**
     * Retrieves the student's score.
     * @return the score of the student
     */
    public int getScore() {
        return score;
    }

    /**
     * Updates the student's score.
     * @param score the new score to set
     */
    public void setScore(int score) {
        this.score = score;
    }

    /**
     * Returns a string representation of the Student.
     * @return a formatted string with the student's name and score
     */
    public String toString() {
        return "name: " + name + ", score: " + score;
    }

    /**
     * Checks equality based on the student's name.
     * Two students are considered equal if their names are the same.
     * @param obj the object to compare
     * @return true if the names are equal, false otherwise
     */
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }

        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }

        Student student = (Student) obj;

        return name.equals(student.name);
    }
}
